@@ -1,57 +1,55 @@
 /*
- * Copyright (c) 2000 Silicon Graphics, Inc.  All Rights Reserved.
- * 
+ * Copyright (c) 2000-2001,2005 Silicon Graphics, Inc.  All Rights Reserved.
+ *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
  * published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it would be useful, but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
- * 
+ *
  * Further, this software is distributed without any warranty that it is
  * free of the rightful claim of any third person regarding infringement
  * or the like.  Any license provided herein, whether implied or
  * otherwise, applies only to this software file.  Patent licenses, if
  * any, provided herein do not apply to combinations of this program with
  * other software, or any other product whatsoever.
- * 
+ *
  * You should have received a copy of the GNU General Public License along
  * with this program; if not, write the Free Software Foundation, Inc., 59
  * Temple Place - Suite 330, Boston MA 02111-1307, USA.
- * 
+ *
  * Contact information: Silicon Graphics, Inc., 1600 Amphitheatre Pkwy,
  * Mountain View, CA  94043, or:
- * 
- * http://www.sgi.com 
- * 
- * For further information regarding this notice, see: 
- * 
+ *
+ * http://www.sgi.com
+ *
+ * For further information regarding this notice, see:
+ *
  * http://oss.sgi.com/projects/GenInfo/SGIGPLNoticeExplan/
  */
 
-#include <libxfs.h>
-#include <getopt.h>
+#include <xfs/libxfs.h>
 #include "bit.h"
 #include "bmap.h"
 #include "command.h"
-#include "data.h"
-#include "dquot.h"
 #include "type.h"
 #include "faddr.h"
 #include "fprint.h"
 #include "field.h"
 #include "inode.h"
 #include "io.h"
-#include "mount.h"
+#include "init.h"
 #include "output.h"
+#include "dquot.h"
 
 static int	dquot_f(int argc, char **argv);
 static void	dquot_help(void);
 
 static const cmdinfo_t	dquot_cmd =
-	{ "dquot", NULL, dquot_f, 1, 2, 1, "[gid|uid]",
-	  "set current address to group or user quota block", dquot_help };
+	{ "dquot", NULL, dquot_f, 1, 2, 1, "[projid|gid|uid]",
+	  "set current address to project, group or user quota block", dquot_help };
 
 const field_t	dqblk_hfld[] = {
 	{ "", FLDT_DQBLK, OI(0), C1, 0, TYP_NONE },
@@ -112,6 +110,7 @@ dquot_f(
 	bmap_ext_t	bm;
 	int		c;
 	int		dogrp;
+	int		doprj;
 	xfs_dqid_t	id;
 	xfs_ino_t	ino;
 	int		nex;
@@ -121,27 +120,34 @@ dquot_f(
 	int		qoff;
 	char		*s;
 
-	dogrp = optind = 0;
-	while ((c = getopt(argc, argv, "gu")) != EOF) {
+	dogrp = doprj = optind = 0;
+	while ((c = getopt(argc, argv, "gpu")) != EOF) {
 		switch (c) {
 		case 'g':
 			dogrp = 1;
+			doprj = 0;
+			break;
+		case 'p':
+			doprj = 1;
+			dogrp = 0;
 			break;
 		case 'u':
-			dogrp = 0;
+			dogrp = doprj = 0;
 			break;
 		default:
 			dbprintf("bad option for dquot command\n");
 			return 0;
 		}
 	}
-	s = dogrp ? "group" : "user";
+	s = doprj ? "project" : dogrp ? "group" : "user";
 	if (optind != argc - 1) {
 		dbprintf("dquot command requires one %s id argument\n", s);
 		return 0;
 	}
-	ino = dogrp ? mp->m_sb.sb_gquotino : mp->m_sb.sb_uquotino;
-	if (ino == 0 || ino == NULLFSINO) {
+	ino = (dogrp || doprj) ? mp->m_sb.sb_gquotino : mp->m_sb.sb_uquotino;
+	if (ino == 0 || ino == NULLFSINO ||
+	    (dogrp && (mp->m_sb.sb_qflags & XFS_PQUOTA_ACCT)) ||
+	    (doprj && (mp->m_sb.sb_qflags & XFS_GQUOTA_ACCT))) {
 		dbprintf("no %s quota inode present\n", s);
 		return 0;
 	}
