@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2003-2004 Silicon Graphics, Inc.  All Rights Reserved.
+ * Copyright (c) 2003-2005 Silicon Graphics, Inc.  All Rights Reserved.
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of version 2 of the GNU General Public License as
@@ -54,6 +54,8 @@ pwrite_help(void)
 " -i -- specifies an input file from which to source data to write\n"
 " -d -- open the input file for direct IO\n"
 " -s -- skip a number of bytes at the start of the input file\n"
+" -w -- call fdatasync(2) at the end (included in timing results)\n"
+" -W -- call fsync(2) at the end (included in timing results)\n"
 " The writes are performed in sequential blocks starting at offset, with the\n"
 " blocksize tunable using the -b option (default blocksize is 4096 bytes).\n"
 "\n"));
@@ -104,14 +106,16 @@ pwrite_f(
 	off64_t		offset, skip = 0;
 	long long	count, total;
 	unsigned int	seed = 0xcdcdcdcd;
-	unsigned int	blocksize, sectsize;
+	int		blocksize, sectsize;
 	struct timeval	t1, t2;
 	char		s1[64], s2[64], ts[64];
 	char		*sp, *infile = NULL;
-	int		c, fd = -1, uflag = 0, dflag = 0;
+	int		Cflag, uflag, dflag, wflag, Wflag;
+	int		c, fd = -1;
 
+	Cflag = uflag = dflag = wflag = Wflag = 0;
 	init_cvtnum(&blocksize, &sectsize);
-	while ((c = getopt(argc, argv, "b:df:i:s:S:u")) != EOF) {
+	while ((c = getopt(argc, argv, "b:Cdf:i:s:S:uwW")) != EOF) {
 		switch (c) {
 		case 'b':
 			blocksize = cvtnum(blocksize, sectsize, optarg);
@@ -120,6 +124,9 @@ pwrite_f(
 				return 0;
 			}
 			break;
+		case 'C':
+			Cflag = 1;
+			break;
 		case 'd':
 			dflag = 1;
 			break;
@@ -144,6 +151,12 @@ pwrite_f(
 		case 'u':
 			uflag = 1;
 			break;
+		case 'w':
+			wflag = 1;
+			break;
+		case 'W':
+			Wflag = 1;
+			break;
 		default:
 			return command_usage(&pwrite_cmd);
 		}
@@ -175,16 +188,27 @@ pwrite_f(
 		close(fd);
 		return 0;
 	}
+	if (Wflag)
+		fsync(file->fd);
+	if (wflag)
+		fdatasync(file->fd);
 	gettimeofday(&t2, NULL);
 	t2 = tsub(t2, t1);
 
-	printf(_("wrote %lld/%lld bytes at offset %lld\n"),
-		total, count, (long long)offset);
-	cvtstr((double)total, s1, sizeof(s1));
-	cvtstr(tdiv((double)total, t2), s2, sizeof(s2));
-	timestr(&t2, ts, sizeof(ts));
-	printf(_("%s, %d ops; %s (%s/sec and %.4f ops/sec)\n"),
-		s1, c, ts, s2, tdiv((double)c, t2));
+	/* Finally, report back -- -C gives a parsable format */
+	timestr(&t2, ts, sizeof(ts), Cflag ? VERBOSE_FIXED_TIME : 0);
+	if (!Cflag) {
+		cvtstr((double)total, s1, sizeof(s1));
+		cvtstr(tdiv((double)total, t2), s2, sizeof(s2));
+		printf(_("wrote %lld/%lld bytes at offset %lld\n"),
+			total, count, (long long)offset);
+		printf(_("%s, %d ops; %s (%s/sec and %.4f ops/sec)\n"),
+			s1, c, ts, s2, tdiv((double)c, t2));
+	} else {/* bytes,ops,time,bytes/sec,ops/sec */
+		printf("%lld,%d,%s,%.3f,%.3f\n",
+			total, c, ts,
+			tdiv((double)total, t2), tdiv((double)c, t2));
+	}
 	close(fd);
 	return 0;
 }
@@ -199,7 +223,7 @@ pwrite_init(void)
 	pwrite_cmd.argmax = -1;
 	pwrite_cmd.flags = CMD_NOMAP_OK | CMD_FOREIGN_OK;
 	pwrite_cmd.args =
-		_("[-i infile [-d] [-s skip]] [-b bs] [-S seed] off len");
+		_("[-i infile [-d] [-s skip]] [-b bs] [-S seed] [-wW] off len");
 	pwrite_cmd.oneline =
 		_("writes a number of bytes at a specified offset");
 	pwrite_cmd.help = pwrite_help;
